@@ -10,17 +10,17 @@
 // Any improvements should be done at kdepim-runtime and
 // than afterwards copy the new version
 
-#ifndef PIMCOMMON_IMAPACLATTRIBUTE_H
-#define PIMCOMMON_IMAPACLATTRIBUTE_H
+#pragma once
 
 #include "pimcommonakonadi_export.h"
 
-#include <Attribute>
+#include <Akonadi/Attribute>
 
 #include <KIMAP/Acl>
 
 #include <QMap>
 
+#include <memory>
 namespace PimCommon
 {
 class ImapAclAttributePrivate;
@@ -46,11 +46,9 @@ public:
     bool operator==(const ImapAclAttribute &other) const;
 
 private:
-    ImapAclAttributePrivate *const d;
+    std::unique_ptr<ImapAclAttributePrivate> const d;
     QMap<QByteArray, KIMAP::Acl::Rights> mRights;
     QMap<QByteArray, KIMAP::Acl::Rights> mOldRights;
     KIMAP::Acl::Rights mMyRights;
 };
 }
-
-#endif
