@@ -38,9 +38,11 @@ public:
 
     Q_REQUIRED_RESULT QHash<QString, bool> blackListItemChanged() const;
 
-    void setExcludeDomain(const QStringList &domain);
+    void setExcludeDomains(const QStringList &domain);
     Q_REQUIRED_RESULT int setEmailFound(const QStringList &);
 
+    void setExcludeEmailsRegularExpressions(const QStringList &newExcludeEmailsRegularExpressions);
+
 protected:
     void paintEvent(QPaintEvent *event) override;
 
@@ -48,8 +50,9 @@ protected:
 
 private:
     void generalPaletteChanged();
+    QStringList mExcludeEmailsRegularExpressions;
     QStringList mEmailBlackList;
-    QStringList mExcludeDomain;
+    QStringList mExcludeDomains;
     QColor mTextColor;
     bool mFirstResult = false;
 };
