@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -32,8 +32,7 @@ public:
     void setParentWidget(QWidget *parentWidget);
 
 private:
-    void slotConfigureSubscriptionFinished(QDBusPendingCallWatcher *watcher);
+    PIMCOMMONAKONADI_NO_EXPORT void slotConfigureSubscriptionFinished(QDBusPendingCallWatcher *watcher);
     std::unique_ptr<ManageServerSideSubscriptionJobPrivate> const d;
 };
 }
-
